==> wiki-security-passportjs-0.1.0-1.tgz: package/client/security.js <==
(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){

/*
 * Federated Wiki : Social Security Plugin
 *
 * Licensed under the MIT license.
 * https://github.com/fedwiki/wiki-security-social/blob/master/LICENSE.txt
 */

/*
1. Display login button - if there is no authenticated user
2. Display logout button - if the user is authenticated

3. When user authenticated, claim site if unclaimed - and repaint footer.
 */
var claim_wiki, setup, update_footer;

claim_wiki = function() {
  var myInit;
  if (!isClaimed) {
    myInit = {
      method: 'GET',
      cache: 'no-cache',
      mode: 'same-origin',
      credentials: 'include'
    };
    return fetch('/auth/claim-wiki', myInit).then(function(response) {
      if (response.ok) {
        return response.json().then(function(json) {
          var ownerName;
          ownerName = json.ownerName;
          update_footer(ownerName, true, true);
          return console.log('owner: ', json.ownerName, ' : ', ownerName);
        });
      } else {
        return console.log('Attempt to claim site failed', response);
      }
    });
  }
};

update_footer = function(ownerName, isAuthenticated, isOwner) {
  var signonTitle;
  if (ownerName) {
    $('footer > #site-owner').html("Site Owned by: <span id='site-owner' style='text-transform:capitalize;'>" + ownerName + "</span>");
  }
  $('footer > #security').empty();
  if (isAuthenticated) {
    $('footer > #security').append("<a href='#' id='logout' class='footer-item' title='Sign-out'><i class='fa fa-unlock fa-lg fa-fw'></i></a>");
    return $('footer > #security > #logout').click(function(e) {
      var myInit;
      e.preventDefault();
      myInit = {
        method: 'GET',
        cache: 'no-cache',
        mode: 'same-origin',
        credentials: 'include'
      };
      return fetch('/logout', myInit).then(function(response) {
        var user;
        if (response.ok) {
          isAuthenticated = false;
          isOwner = false;
          user = '';
          return update_footer(ownerName, isAuthenticated, isOwner);
        } else {
          return console.log('logout failed: ', response);
        }
      });
    });
  } else {
    if (!isClaimed) {
      signonTitle = 'Claim this Wiki';
    } else {
      signonTitle = 'Sign-on';
    }
    $('footer > #security').append("<a href='#' id='show-security-dialog' class='footer-item' title='" + signonTitle + "'><i class='fa fa-lock fa-lg fa-fw'></i></a>");
    return $('footer > #security > #show-security-dialog').click(function(e) {
      var securityDialog;
      e.preventDefault();
      securityDialog = window.open("/auth/loginDialog", "_blank", "width=700, height=375, menubar=no, location=no, chrome=yes, centerscreen");
      return securityDialog.window.focus();
    });
  }
};

setup = function(user) {
  if (!$("link[href='https://maxcdn.bootstrapcdn.com/font-awesome/4.5.0/css/font-awesome.min.css']").length) {
    $('<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.5.0/css/font-awesome.min.css">').appendTo("head");
  }
  if (!$("link[href='/security/style.css']").length) {
    $('<link rel="stylesheet" href="/security/style.css">').appendTo("head");
  }
  return update_footer(ownerName, isAuthenticated, isOwner);
};

window.plugins.security = {
  setup: setup,
  claim_wiki: claim_wiki,
  update_footer: update_footer
};


},{}]},{},[1]);

==> wiki-security-passportjs-0.1.0-3.tgz: package/client/security.js <==
(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){

/*
 * Federated Wiki : Social Security Plugin
 *
 * Licensed under the MIT license.
 * https://github.com/fedwiki/wiki-security-social/blob/master/LICENSE.txt
 */

/*
1. Display login button - if there is no authenticated user
2. Display logout button - if the user is authenticated

3. When user authenticated, claim site if unclaimed - and repaint footer.
 */
var claim_wiki, settings, setup, update_footer;

settings = {};

claim_wiki = function() {
  var myInit;
  if (!isClaimed) {
    myInit = {
      method: 'GET',
      cache: 'no-cache',
      mode: 'same-origin',
      credentials: 'include'
    };
    return fetch('/auth/claim-wiki', myInit).then(function(response) {
      if (response.ok) {
        return response.json().then(function(json) {
          var ownerName;
          ownerName = json.ownerName;
          return update_footer(ownerName, true, true);
        });
      } else {
        return console.log('Attempt to claim site failed', response);
      }
    });
  }
};

update_footer = function(ownerName, isAuthenticated, isOwner) {
  var signonTitle;
  if (ownerName) {
    $('footer > #site-owner').html("Site Owned by: <span id='site-owner' style='text-transform:capitalize;'>" + ownerName + "</span>");
  }
  $('footer > #security').empty();
  if (isAuthenticated) {
    $('footer > #security').append("<a href='#' id='logout' class='footer-item' title='Sign-out'><i class='fa fa-unlock fa-lg fa-fw'></i></a>");
    return $('footer > #security > #logout').click(function(e) {
      var myInit;
      e.preventDefault();
      myInit = {
        method: 'GET',
        cache: 'no-cache',
        mode: 'same-origin',
        credentials: 'include'
      };
      return fetch('/logout', myInit).then(function(response) {
        var user;
        if (response.ok) {
          isAuthenticated = false;
          isOwner = false;
          user = '';
          return update_footer(ownerName, isAuthenticated, isOwner);
        } else {
          return console.log('logout failed: ', response);
        }
      });
    });
  } else {
    if (!isClaimed) {
      signonTitle = 'Claim this Wiki';
    } else {
      signonTitle = 'Wiki Owner Sign-on';
    }
    $('footer > #security').append("<a href='#' id='show-security-dialog' class='footer-item' title='" + signonTitle + "'><i class='fa fa-lock fa-lg fa-fw'></i></a>");
    return $('footer > #security > #show-security-dialog').click(function(e) {
      var w;
      e.preventDefault();
      return w = WinChan.open({
        url: settings.dialogURL,
        relay_url: settings.relayURL,
        window_features: "menubar=0, location=0, resizable=0, scrollbars=0, status=0, dialog=1, width=700, height=375",
        params: {}
      }, function(err, r) {
        if (err) {
          return console.log(err);
        } else if (!isClaimed) {
          return claim_wiki();
        } else {
          return update_footer(ownerName, true);
        }
      });
    });
  }
};

setup = function(user) {
  var myInit;
  if (!$("link[href='https://maxcdn.bootstrapcdn.com/font-awesome/4.5.0/css/font-awesome.min.css']").length) {
    $('<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.5.0/css/font-awesome.min.css">').appendTo("head");
  }
  wiki.getScript('/security/winchan.js');
  if (!$("link[href='/security/style.css']").length) {
    $('<link rel="stylesheet" href="/security/style.css">').appendTo("head");
  }
  myInit = {
    method: 'GET',
    cache: 'no-cache',
    mode: 'same-origin'
  };
  return fetch('/auth/client-settings.json', myInit).then(function(response) {
    if (response.ok) {
      return response.json().then(function(json) {
        var dialogHost, dialogProtocol;
        settings = json;
        if (settings.useHttps) {
          dialogProtocol = 'https:';
        } else {
          dialogProtocol = window.location.protocol;
        }
        if (settings.wikiHost) {
          dialogHost = settings.wikiHost;
        } else {
          dialogHost = window.location.host;
        }
        settings.dialogURL = dialogProtocol + '//' + dialogHost + '/auth/loginDialog';
        settings.relayURL = dialogProtocol + '//' + dialogHost + '/auth/relay.html';
        return update_footer(ownerName, isAuthenticated, isOwner);
      });
    } else {
      return console.log('Unable to fetch client settings: ', response);
    }
  });
};

window.plugins.security = {
  setup: setup,
  claim_wiki: claim_wiki,
  update_footer: update_footer
};


},{}]},{},[1]);
